@@ -20,11 +20,6 @@
 
 #define HAVE_STDLIB_H
 
-/* Define if your processor stores words with the most significant
-   byte first (like Motorola and SPARC, unlike Intel and VAX). */
-
-#define WORDS_BIGENDIAN
-
 /* Define if the X Window System is missing or not being used. */
 
 #define X_DISPLAY_MISSING
@@ -96,6 +91,18 @@
 #define  TT_CONFIG_OPTION_GRAY_SCALING
 
 
+/*************************************************************************/
+/* Define this if you want to completely disable the use of the bytecode */
+/* interpreter.  Doing so will produce a much smaller library, but the   */
+/* quality of the rendered glyphs will enormously suffer from this.      */
+/*                                                                       */
+/* This switch was introduced due to the Apple patents issue which       */
+/* emerged recently on the FreeType lists.  We still do not have Apple's */
+/* opinion on the subject and will change this as soon as we have.       */
+
+#undef   TT_CONFIG_OPTION_NO_INTERPRETER
+
+
 /*************************************************************************/
 /* Define this if you want to use a big 'switch' statement within the    */
 /* bytecode interpreter. Because some non-optimizing compilers are not   */
@@ -107,12 +114,34 @@
 #define  TT_CONFIG_OPTION_INTERPRETER_SWITCH
 
 
+/*************************************************************************/
+/* Define this if you want to build a 'static' version of the TrueType   */
+/* bytecode interpreter. This will produce much bigger code, which       */
+/* _may_ be faster on some architectures..                               */
+/*                                                                       */
+/* Do NOT DEFINE THIS is you build a thread-safe version of the engine   */
+/*                                                                       */
+#undef TT_CONFIG_OPTION_STATIC_INTERPRETER
+
+
+/*************************************************************************/
+/* Define this if you want to build a 'static' version of the scan-line  */
+/* converter (the component which in charge of converting outlines into  */
+/* bitmaps). This will produce a bigger object file for "ttraster.c",    */
+/* which _may_ be faster on some architectures..                         */
+/*                                                                       */
+/* Do NOT DEFINE THIS is you build a thread-safe version of the engine   */
+/*                                                                       */
+#undef  TT_CONFIG_OPTION_STATIC_RASTER
+
+
 /*************************************************************************/
 /* Define TT_CONFIG_THREAD_SAFE if you want to build a thread-safe       */
 /* version of the library.                                               */
 
 #undef  TT_CONFIG_OPTION_THREAD_SAFE
 
+
 /**********************************************************************/
 /*                                                                    */
 /*  The following macros are used to define the debug level, as well  */
@@ -188,4 +217,4 @@
 #endif /* FT_CONF_H */
 
 
-/* End of ft_conf.h */
+/* END */
