@@ -4,7 +4,7 @@
  *
  *    High-level interface specification.
  *
- *  Copyright 1996-1998 by
+ *  Copyright 1996-1999 by
  *  David Turner, Robert Wilhelm, and Werner Lemberg.
  *
  *  This file is part of the FreeType project and may only be used,
@@ -17,7 +17,7 @@
  *
  *    This is the only file that should be included by client
  *    application sources.  All other types and functions defined
- *    in the "tt*.h" files are library internals and should not be
+ *    in the `tt*.h' files are library internals and should not be
  *    included.
  *
  ******************************************************************/
@@ -27,7 +27,7 @@
 
 
 #define TT_FREETYPE_MAJOR  1
-#define TT_FREETYPE_MINOR  1
+#define TT_FREETYPE_MINOR  3
 
 
 #include "fterrid.h"
@@ -37,7 +37,7 @@
 /* whether EXPORT_DEF has been defined already.                     */
 
 #ifndef EXPORT_DEF
-#define EXPORT_DEF extern
+#define EXPORT_DEF  extern
 #endif
 
 /* The same for TT_Text.  If you define the HAVE_TT_TEXT macro, you */
@@ -46,8 +46,8 @@
 
 #ifndef HAVE_TT_TEXT
 #define HAVE_TT_TEXT
-  typedef char  TT_Text;              /* the data type to represent */
-                                      /* file name string elements  */
+  typedef char  TT_Text;              /* The data type to represent */
+                                      /* file name string elements. */
 #endif
 
 #ifdef __cplusplus
@@ -63,43 +63,43 @@
   /*                                                                 */
   /*******************************************************************/
 
-  typedef unsigned short  TT_Bool;
+  typedef int             TT_Bool;
 
-  typedef signed long     TT_Fixed;   /* Signed Fixed 16.16 Float */
+  typedef signed long     TT_Fixed;   /* signed fixed 16.16 float */
 
-  typedef signed short    TT_FWord;   /* Distance in FUnits */
-  typedef unsigned short  TT_UFWord;  /* Unsigned distance */
+  typedef signed short    TT_FWord;   /* distance in FUnits */
+  typedef unsigned short  TT_UFWord;  /* unsigned distance  */
 
   typedef char            TT_String;
   typedef signed char     TT_Char;
   typedef unsigned char   TT_Byte;
   typedef signed short    TT_Short;
   typedef unsigned short  TT_UShort;
+  typedef int             TT_Int;
+  typedef unsigned int    TT_UInt;
   typedef signed long     TT_Long;
   typedef unsigned long   TT_ULong;
 
   typedef signed short    TT_F2Dot14; /* Signed fixed float 2.14 used for */
-                                      /* unit vectors, with layout:       */
+                                      /* unit vectors, with layout        */
                                       /*                                  */
-                                      /*  s : 1  -- sign bit              */
-                                      /*  m : 1  -- integer bit           */
-                                      /*  f : 14 -- unsigned fractional   */
-                                      /*                                  */
-                                      /*  's:m' is the 2-bit signed int   */
-                                      /*  value to which the positive     */
-                                      /*  fractional part should be       */
-                                      /*  added.                          */
+                                      /*   s : 1  -- sign bit             */
+                                      /*   m : 1  -- integer bit          */
+                                      /*   f : 14 -- unsigned fractional  */
                                       /*                                  */
+                                      /* `s:m' is the 2-bit signed int    */
+                                      /* value to which the positive      */
+                                      /* fractional part should be added. */
 
   typedef signed long     TT_F26Dot6; /* 26.6 fixed float, used for       */
                                       /* glyph points pixel coordinates.  */
 
-  typedef signed long     TT_Pos;     /* point position, expressed either */
+  typedef signed long     TT_Pos;     /* Point position, expressed either */
                                       /* in fractional pixels or notional */
                                       /* units, depending on context.     */
                                       /* For example, glyph coordinates   */
-                                      /* returned by TT_Load_Glyph are    */
-                                      /* expressed in font units when     */
+                                      /* returned by TT_Load_Glyph() are  */
+                                      /* expressed in font units if       */
                                       /* scaling wasn't requested, and    */
                                       /* in 26.6 fractional pixels if it  */
                                       /* was.                             */
@@ -114,7 +114,7 @@
   typedef struct TT_UnitVector_  TT_UnitVector;
 
 
-  struct  TT_Vector_          /* Simple vector type */
+  struct  TT_Vector_          /* simple vector type */
   {
     TT_F26Dot6  x;
     TT_F26Dot6  y;
@@ -126,8 +126,8 @@
   /* A simple 2x2 matrix used for transformations. */
   /* You should use 16.16 fixed floats.            */
   /*                                               */
-  /*  x' = xx*x + xy*y                             */
-  /*  y' = yx*x + yy*y                             */
+  /*   x' = xx*x + xy*y                            */
+  /*   y' = yx*x + yy*y                            */
   /*                                               */
 
   struct  TT_Matrix_
@@ -143,8 +143,8 @@
 
   struct  TT_Outline_
   {
-    TT_Short         n_contours;   /* number of contours in glyph        */
-    TT_UShort        n_points;     /* number of points in the glyph      */
+    TT_Short         n_contours;   /* number of contours in glyph   */
+    TT_UShort        n_points;     /* number of points in the glyph */
 
     TT_Vector*       points;       /* the outline's points   */
     TT_Byte*         flags;        /* the points flags       */
@@ -155,40 +155,40 @@
     /* TT_New_Outline() API, while it isn't for those returned by        */
     /* TT_Get_Glyph_Outline().                                           */
 
-    TT_Bool          owner;      /* the outline owns the coordinates,    */
-                                 /* flags and contours array it uses     */
+    TT_Bool          owner;      /* The outline owns the coordinates, */
+                                 /* flags and contours array it uses. */
 
     /* The following flags are set automatically by                      */
     /* TT_Get_Glyph_Outline().  Their meaning is the following:          */
     /*                                                                   */
-    /*  high_precision   When true, the scan-line converter will use     */
-    /*                   a higher precision to render bitmaps (i.e. a    */
+    /*  high_precision   If true, the scan-line converter will use a     */
+    /*                   higher precision to render bitmaps (i.e., a     */
     /*                   1/1024 pixel precision).  This is important for */
     /*                   small ppem sizes.                               */
     /*                                                                   */
-    /*  second_pass      When true, the scan-line converter performs     */
-    /*                   a second sweep phase dedicated to find          */
-    /*                   vertical drop-outs.  If false, only horizontal  */
-    /*                   drop-outs will be checked during the first      */
-    /*                   vertical sweep (yes, this is a bit confusing    */
-    /*                   but it's really the way it should work).        */
-    /*                   This is important for small ppems too.          */
+    /*  second_pass      If true, the scan-line converter performs a     */
+    /*                   second sweep phase dedicated to find vertical   */
+    /*                   drop-outs.  If false, only horizontal drop-outs */
+    /*                   will be checked during the first vertical       */
+    /*                   sweep (yes, this is a bit confusing but it is   */
+    /*                   really the way it should work).  This is        */
+    /*                   important for small ppems too.                  */
     /*                                                                   */
-    /*  dropout_mode     Specifies the TrueType drop-out mode to         */
-    /*                   use for continuity checking. valid values       */
-    /*                   are 0 (no check), 1, 2, 4, and 5.               */
+    /*  dropout_mode     Specifies the TrueType drop-out mode to use for */
+    /*                   continuity checking.  Valid values are 0 (no    */
+    /*                   check), 1, 2, 4, and 5.                         */
     /*                                                                   */
     /*  Most of the engine's users will safely ignore these fields...    */
 
     TT_Bool          high_precision;  /* high precision rendering */
     TT_Bool          second_pass;     /* two sweeps rendering     */
-    TT_Char          dropout_mode;    /* dropout mode */
+    TT_Char          dropout_mode;    /* dropout mode             */
   };
 
   typedef struct TT_Outline_  TT_Outline;
 
 
-  /* A structure used to describe a simple bounding box */
+  /* A structure used to describe a simple bounding box. */
 
   struct TT_BBox_
   {
@@ -203,21 +203,17 @@
 
   /* A structure used to return glyph metrics.                          */
   /*                                                                    */
-  /* The "bearingX" isn't called "left-side bearing" anymore because    */
+  /* The `bearingX' isn't called `left-side bearing' anymore because    */
   /* it has different meanings depending on the glyph's orientation.    */
   /*                                                                    */
-  /* The same is true for "bearingY", which is the top-side bearing     */
+  /* The same is true for `bearingY', which is the top-side bearing     */
   /* defined by the TT_Spec, i.e., the distance from the baseline to    */
   /* the top of the glyph's bbox.  According to our current convention, */
-  /* this is always the same as "bbox.yMax" but we make it appear for   */
+  /* this is always the same as `bbox.yMax' but we make it appear for   */
   /* consistency in its proper field.                                   */
   /*                                                                    */
-  /* The "advance" width is the advance width for horizontal layout,    */
+  /* The `advance' field is the advance width for horizontal layout,    */
   /* and advance height for vertical layouts.                           */
-  /*                                                                    */
-  /* Finally, the library (ver. 1.1) doesn't support vertical text yet  */
-  /* but these changes were introduced to accomodate it, as it will     */
-  /* most certainly be introduced in later releases.                    */
 
   struct  TT_Glyph_Metrics_
   {
@@ -229,15 +225,15 @@
     TT_Pos   advance;   /* advance width (or height) */
   };
 
+  typedef struct TT_Glyph_Metrics_  TT_Glyph_Metrics;
+
 
   /* A structure used to return horizontal _and_ vertical glyph         */
   /* metrics.                                                           */
   /*                                                                    */
   /* A glyph can be used either in a horizontal or vertical layout.     */
-  /* Its glyph metrics vary with orientation.  The Big_Glyph_Metrics    */
+  /* Its glyph metrics vary with orientation.  The TT_Big_Glyph_Metrics */
   /* structure is used to return _all_ metrics in one call.             */
-  /*                                                                    */
-  /* This structure is currently unused.                                */
 
   struct TT_Big_Glyph_Metrics_
   {
@@ -268,7 +264,6 @@
     TT_Pos   linearVertAdvance;   /* linearly scaled vertical advance */
   };
 
-  typedef struct TT_Glyph_Metrics_      TT_Glyph_Metrics;
   typedef struct TT_Big_Glyph_Metrics_  TT_Big_Glyph_Metrics;
 
 
@@ -296,10 +291,10 @@
   /* The flow of a bitmap refers to the way lines are oriented   */
   /* within the bitmap data, i.e., the orientation of the Y      */
   /* coordinate axis.                                            */
-
+  /*                                                             */
   /* For example, if the first bytes of the bitmap pertain to    */
-  /* its top-most line, then the flow is 'down'.  If these bytes */
-  /* pertain to its lowest line, the the flow is 'up'.           */
+  /* its top-most line, then the flow is `down'.  If these bytes */
+  /* pertain to its lowest line, the the flow is `up'.           */
 
 #define TT_Flow_Down  -1  /* bitmap is oriented from top to bottom */
 #define TT_Flow_Up     1  /* bitmap is oriented from bottom to top */
@@ -309,24 +304,24 @@
   /* A structure used to describe the target bitmap or pixmap to the   */
   /* renderer.  Note that there is nothing in this structure that      */
   /* gives the nature of the buffer.                                   */
-
+  /*                                                                   */
   /* IMPORTANT NOTE:                                                   */
   /*                                                                   */
-  /*   In the case of a pixmap, the 'width' and 'cols' fields must     */
+  /*   In the case of a pixmap, the `width' and `cols' fields must     */
   /*   have the _same_ values, and _must_ be padded to 32-bits, i.e.,  */
   /*   be a multiple of 4.  Clipping problems will arise otherwise,    */
   /*   if not even page faults!                                        */
   /*                                                                   */
   /*   The typical settings are:                                       */
   /*                                                                   */
-  /*   - for an WxH bitmap:                                            */
+  /*   - for a WxH bitmap:                                             */
   /*                                                                   */
   /*       rows  = H                                                   */
-  /*       cols  = (W+7)/8                                             */
+  /*       cols  = (W+7) / 8                                           */
   /*       width = W                                                   */
   /*       flow  = your_choice                                         */
   /*                                                                   */
-  /*   - for an WxH pixmap:                                            */
+  /*   - for a WxH pixmap:                                             */
   /*                                                                   */
   /*       rows  = H                                                   */
   /*       cols  = (W+3) & ~3                                          */
@@ -347,7 +342,7 @@
   typedef struct TT_Raster_Map_  TT_Raster_Map;
 
 
-  /* ------- The font header TrueType table structure ----- */
+  /* ------ The font header TrueType table structure ------ */
 
   struct  TT_Header_
   {
@@ -379,7 +374,7 @@
   typedef struct TT_Header_  TT_Header;
 
 
-  /* ------- The horizontal header TrueType table structure ----- */
+  /* ------ The horizontal header TrueType table structure ------ */
 
   /*******************************************************/
   /*  This structure is the one defined by the TrueType  */
@@ -401,19 +396,25 @@
     TT_FWord   caret_Slope_Rise;
     TT_FWord   caret_Slope_Run;
 
-    TT_Short   Reserved[5];
+    TT_Short   Reserved0,
+               Reserved1,
+               Reserved2,
+               Reserved3,
+               Reserved4;
 
     TT_Short   metric_Data_Format;
     TT_UShort  number_Of_HMetrics;
 
     /* The following fields are not defined by the TrueType specification */
     /* but they're used to connect the metrics header to the relevant     */
-    /* "HMTX" or "VMTX" table.                                            */
+    /* `HMTX' or `VMTX' table.                                            */
 
     void*      long_metrics;
     void*      short_metrics;
   };
 
+  typedef struct TT_Horizontal_Header_  TT_Horizontal_Header;
+
 
   /*******************************************************/
   /*  This structure is the one defined by the TrueType  */
@@ -437,25 +438,31 @@
     TT_FWord   caret_Slope_Run;
     TT_FWord   caret_Offset;
 
-    TT_Short   Reserved[4];
+    TT_Short   Reserved1,
+               Reserved2,
+               Reserved3,
+               Reserved4;
 
     TT_Short   metric_Data_Format;
     TT_UShort  number_Of_VMetrics;
 
     /* The following fields are not defined by the TrueType specification */
     /* but they're used to connect the metrics header to the relevant     */
-    /* "HMTX" or "VMTX" table.                                            */
+    /* `HMTX' or `VMTX' table.                                            */
 
     void*      long_metrics;
     void*      short_metrics;
   };
 
-
-  typedef struct TT_Horizontal_Header_  TT_Horizontal_Header;
-  typedef struct TT_Vertical_Header_    TT_Vertical_Header;
+  typedef struct TT_Vertical_Header_  TT_Vertical_Header;
 
 
-  /* ----------- OS/2 Table ----------------------------- */
+  /* ------ The OS/2 table ------ */
+
+  /************************************************************************/
+  /* Note that since FreeType 1.3, we support Mac fonts which do not have */
+  /* an OS/2 table.  In this case the `version' field will be set to      */
+  /* 0xFFFF by the table loader; all other fields should be 0.            */
 
   struct  TT_OS2_
   {
@@ -503,7 +510,7 @@
   typedef struct TT_OS2_  TT_OS2;
 
 
-  /* ----------- Postscript table ------------------------ */
+  /* ------ The PostScript table ------ */
 
   struct  TT_Postscript_
   {
@@ -524,7 +531,7 @@
   typedef struct TT_Postscript_  TT_Postscript;
 
 
-  /* ------------ horizontal device metrics "hdmx" ---------- */
+  /* ------ The horizontal device metrics table (`hdmx') ------ */
 
   struct  TT_Hdmx_Record_
   {
@@ -565,20 +572,19 @@
     TT_Horizontal_Header*  horizontal;    /* TrueType horizontal header     */
     TT_OS2*                os2;           /* TrueType OS/2 table            */
     TT_Postscript*         postscript;    /* TrueType Postscript table      */
-    TT_Hdmx*               hdmx;
+    TT_Hdmx*               hdmx;          /* TrueType hor. dev. metr. table */
     TT_Vertical_Header*    vertical;      /* TT Vertical header, if present */
   };
 
   typedef struct TT_Face_Properties_  TT_Face_Properties;
 
 
-
   /* Here are the definitions of the handle types used for FreeType's */
   /* most common objects accessed by the client application.  We use  */
-  /* a simple trick there:                                            */
+  /* a simple trick:                                                  */
   /*                                                                  */
   /*   Each handle type is a structure that only contains one         */
-  /*   pointer.  The advantage of structures is that there are        */
+  /*   pointer.  The advantage of structures is that they are         */
   /*   mutually exclusive types.  We could have defined the           */
   /*   following types:                                               */
   /*                                                                  */
@@ -615,20 +621,29 @@
   typedef struct TT_Glyph_     TT_Glyph;     /* glyph handle type         */
   typedef struct TT_CharMap_   TT_CharMap;   /* character map handle type */
 
-  typedef long  TT_Error;
 
+  /* Almost all functions return an error code of this type. */
+
+  typedef long  TT_Error;
 
 
   /*******************************************************************/
   /*                                                                 */
   /*  FreeType API                                                   */
   /*                                                                 */
-  /*  All these begin with a 'TT_' prefix.                           */
+  /*  All these begin with a `TT_' prefix.                           */
   /*                                                                 */
-  /*  Most of them are implemented in the 'ttapi.c' source file.     */
+  /*  Most of them are implemented in the `ttapi.c' source file.     */
   /*                                                                 */
   /*******************************************************************/
 
+  /* Get version information. */
+
+  EXPORT_DEF
+  TT_Error  TT_FreeType_Version( int  *major,
+                                 int  *minor );
+
+
   /* Initialize the engine. */
 
   EXPORT_DEF
@@ -658,15 +673,15 @@
 
   /* ----------------------- face management ----------------------- */
 
-  /* Open a new TrueType font file, and returns a handle for */
-  /* it in variable '*face'.                                 */
-
+  /* Open a new TrueType font file, and returns a handle for  */
+  /* it in variable '*face'.                                  */
+  /*                                                          */
   /* Note: The file can be either a TrueType file (*.ttf) or  */
   /*       a TrueType collection (*.ttc, in this case, only   */
   /*       the first face is opened).  The number of faces in */
   /*       the same collection can be obtained in the face's  */
   /*       properties, using TT_Get_Face_Properties() and the */
-  /*       'max_Faces' field.                                 */
+  /*       `max_Faces' field.                                 */
 
   EXPORT_DEF
   TT_Error  TT_Open_Face( TT_Engine       engine,
@@ -675,7 +690,7 @@
 
 
   /* Open a TrueType font file located inside a collection. */
-  /* The font is assigned by its index in 'fontIndex'.      */
+  /* The font is assigned by its index in `fontIndex'.      */
 
   EXPORT_DEF
   TT_Error  TT_Open_Collection( TT_Engine       engine,
@@ -684,7 +699,12 @@
                                 TT_Face*        face );
 
 
-  /* Return face properties in the 'properties' structure. */
+  /* Return face properties in the `properties' structure.          */
+  /*                                                                */
+  /* Note that since version 1.3, we support font files with no     */
+  /* OS/2 table (mainly old Mac fonts).  In this case, the OS/2     */
+  /* `version' field will be set to 0xFFFF, and all other fields    */
+  /* will be zeroed.                                                */
 
   EXPORT_DEF
   TT_Error  TT_Get_Face_Properties( TT_Face              face,
@@ -701,7 +721,7 @@
   /* Get a face object's generic pointer */
 
   EXPORT_DEF
-  void*     TT_Get_Face_Pointer( TT_Face  face );
+  void*  TT_Get_Face_Pointer( TT_Face  face );
 
 
   /* Close a face's file handle to save system resources.  The file */
@@ -710,9 +730,9 @@
   EXPORT_DEF
   TT_Error  TT_Flush_Face( TT_Face  face );
 
-  /* Get a face's glyph metrics expressed in font units.  Returns any   */
-  /* number of arrays.  Set the fields to NULL if you're not interested */
-  /* by a given array.                                                  */
+  /* Get a face's glyph metrics expressed in font units.  Returns any    */
+  /* number of arrays.  Set the fields to NULL if you are not interested */
+  /* by a given array.                                                   */
 
   EXPORT_DEF
   TT_Error  TT_Get_Face_Metrics( TT_Face     face,
@@ -723,6 +743,7 @@
                                  TT_Short*   topBearings,
                                  TT_UShort*  heights );
 
+
   /* Close a given font object, destroying all associated */
   /* instances.                                           */
 
@@ -753,7 +774,7 @@
   /* ----------------------- instance management -------------------- */
 
   /* Open a new font instance and returns an instance handle */
-  /* for it in '*instance'.                                  */
+  /* for it in `*instance'.                                  */
 
   EXPORT_DEF
   TT_Error  TT_New_Instance( TT_Face       face,
@@ -790,9 +811,9 @@
                                         TT_F26Dot6   pointSize );
 
 
-  /* This function has been deprecated !! Do not use it, as it    */
-  /* doesn't work reliably. You can perfectly control hinting     */
-  /* yourself when loading glyphs, then apply transforms as usual */
+  /* This function has been deprecated!  Do not use it, as it      */
+  /* doesn't work reliably.  You can perfectly control hinting     */
+  /* yourself when loading glyphs, then apply transforms as usual. */
 
   EXPORT_DEF
   TT_Error  TT_Set_Instance_Transform_Flags( TT_Instance  instance,
@@ -800,7 +821,7 @@
                                              TT_Bool      stretched );
 
 
-  /* Return instance metrics in 'metrics'. */
+  /* Return instance metrics in `metrics'. */
 
   EXPORT_DEF
   TT_Error  TT_Get_Instance_Metrics( TT_Instance           instance,
@@ -829,7 +850,7 @@
 
   /* ----------------------- glyph management ----------------------- */
 
-  /* Create a new glyph object related to the given 'face'. */
+  /* Create a new glyph object related to the given `face'. */
 
   EXPORT_DEF
   TT_Error  TT_New_Glyph( TT_Face    face,
@@ -844,30 +865,31 @@
 
 #define TTLOAD_SCALE_GLYPH  1
 #define TTLOAD_HINT_GLYPH   2
+#define TTLOAD_PEDANTIC     128
 
 #define TTLOAD_DEFAULT  (TTLOAD_SCALE_GLYPH | TTLOAD_HINT_GLYPH)
 
 
   /* Load and process (scale/transform and hint) a glyph from the */
-  /* given 'instance'.  The glyph and instance handles must be    */
+  /* given `instance'.  The glyph and instance handles must be    */
   /* related to the same face object.  The glyph index can be     */
   /* computed with a call to TT_Char_Index().                     */
-
+  /*                                                              */
   /* The 'load_flags' argument is a combination of the macros     */
   /* TTLOAD_SCALE_GLYPH and TTLOAD_HINT_GLYPH.  Hinting will be   */
   /* applied only if the scaling is selected.                     */
-
-  /* When scaling is off (i.e., load_flags = 0), the returned     */
+  /*                                                              */
+  /* If scaling is off (i.e., load_flags = 0), the returned       */
   /* outlines are in EM square coordinates (also called FUnits),  */
-  /* extracted directly from the font with no hinting.            */
-  /* Other glyph metrics are also in FUnits.                      */
-
-  /* When scaling is on, the returned outlines are in fractional  */
+  /* extracted directly from the font with no hinting.  Other     */
+  /* glyph metrics are also in FUnits.                            */
+  /*                                                              */
+  /* If scaling is on, the returned outlines are in fractional    */
   /* pixel units (i.e. TT_F26Dot6 = 26.6 fixed floats).           */
-
-  /* NOTE:  The glyph index must be in the range 0..num_glyphs-1  */
-  /*        where 'num_glyphs' is the total number of glyphs in   */
-  /*        the font file (given in the face properties).         */
+  /*                                                              */
+  /* NOTE: The glyph index must be in the range 0..num_glyphs-1,  */
+  /*       where `num_glyphs' is the total number of glyphs in    */
+  /*       the font file (given in the face properties).          */
 
   EXPORT_DEF
   TT_Error  TT_Load_Glyph( TT_Instance  instance,
@@ -876,7 +898,7 @@
                            TT_UShort    loadFlags );
 
 
-  /* Return glyph outline pointers in 'outline'.  Note that the returned */
+  /* Return glyph outline pointers in `outline'.  Note that the returned */
   /* pointers are owned by the glyph object, and will be destroyed with  */
   /* it.  The client application should _not_ change the pointers.       */
 
@@ -885,14 +907,14 @@
                                   TT_Outline*  outline );
 
 
-  /* Copy the glyph metrics into 'metrics'. */
+  /* Copy the glyph metrics into `metrics'. */
 
   EXPORT_DEF
   TT_Error  TT_Get_Glyph_Metrics( TT_Glyph           glyph,
                                   TT_Glyph_Metrics*  metrics );
 
 
-  /* Copy the glyph's big metrics into 'metrics'. */
+  /* Copy the glyph's big metrics into `metrics'. */
   /* Necessary to obtain vertical metrics.        */
 
   EXPORT_DEF
@@ -901,12 +923,12 @@
 
 
   /* Render the glyph into a bitmap, with given position offsets.     */
-
-  /*  Note:  Only use integer pixel offsets to preserve the fine      */
-  /*         hinting of the glyph and the 'correct' anti-aliasing     */
-  /*         (where vertical and horizontal stems aren't grayed).     */
-  /*         This means that xOffset and yOffset must be multiples    */
-  /*         of 64!                                                   */
+  /*                                                                  */
+  /* Note: Only use integer pixel offsets to preserve the fine        */
+  /*       hinting of the glyph and the `correct' anti-aliasing       */
+  /*       (where vertical and horizontal stems aren't grayed).  This */
+  /*       means that `xOffset' and `yOffset' must be multiples       */
+  /*       of 64!                                                     */
 
   EXPORT_DEF
   TT_Error  TT_Get_Glyph_Bitmap( TT_Glyph        glyph,
@@ -916,12 +938,12 @@
 
 
   /* Render the glyph into a pixmap, with given position offsets.     */
-
-  /*  Note : Only use integer pixel offsets to preserve the fine      */
-  /*         hinting of the glyph and the 'correct' anti-aliasing     */
-  /*         (where vertical and horizontal stems aren't grayed).     */
-  /*         This means that xOffset and yOffset must be multiples    */
-  /*         of 64!                                                   */
+  /*                                                                  */
+  /* Note: Only use integer pixel offsets to preserve the fine        */
+  /*       hinting of the glyph and the `correct' anti-aliasing       */
+  /*       (where vertical and horizontal stems aren't grayed).  This */
+  /*       means that `xOffset' and `yOffset' must be multiples       */
+  /*       of 64!                                                     */
 
   EXPORT_DEF
   TT_Error  TT_Get_Glyph_Pixmap( TT_Glyph        glyph,
@@ -933,8 +955,8 @@
 
   /* ----------------------- outline support ------------------------ */
 
-  /* Allocate a new outline.  Reserve space for 'numPoints' and */
-  /* 'numContours'.                                             */
+  /* Allocate a new outline.  Reserve space for `numPoints' and */
+  /* `numContours'.                                             */
 
   EXPORT_DEF
   TT_Error  TT_New_Outline( TT_UShort    numPoints,
@@ -963,8 +985,7 @@
                                    TT_Raster_Map*  map );
 
 
-  /* Render an outline into a pixmap -- note that this function uses */
-  /* a different pixel scale, where 1.0 pixels = 128           XXXX  */
+  /* Render an outline into a pixmap. */
 
   EXPORT_DEF
   TT_Error  TT_Get_Outline_Pixmap( TT_Engine       engine,
@@ -974,7 +995,7 @@
 
   /* Return an outline's bounding box -- this function is slow as it */
   /* performs a complete scan-line process, without drawing, to get  */
-  /* the most accurate values.                                 XXXX  */
+  /* the most accurate values.                                       */
 
   EXPORT_DEF
   TT_Error  TT_Get_Outline_BBox( TT_Outline*  outline,
@@ -984,64 +1005,53 @@
   /* Apply a transformation to a glyph outline. */
 
   EXPORT_DEF
-  void      TT_Transform_Outline( TT_Outline*  outline,
-                                  TT_Matrix*   matrix );
+  void  TT_Transform_Outline( TT_Outline*  outline,
+                              TT_Matrix*   matrix );
 
 
   /* Apply a translation to a glyph outline. */
 
   EXPORT_DEF
-  void      TT_Translate_Outline( TT_Outline*  outline,
-                                  TT_F26Dot6   xOffset,
-                                  TT_F26Dot6   yOffset );
+  void  TT_Translate_Outline( TT_Outline*  outline,
+                              TT_F26Dot6   xOffset,
+                              TT_F26Dot6   yOffset );
 
 
   /* Apply a transformation to a vector. */
 
   EXPORT_DEF
-  void      TT_Transform_Vector( TT_F26Dot6*  x,
-                                 TT_F26Dot6*  y,
-                                 TT_Matrix*   matrix );
-
-
-  /* Multiply a matrix with another -- computes "b := a*b". */
-
-  EXPORT_DEF
-  void      TT_Matrix_Multiply( TT_Matrix*  a,
-                                TT_Matrix*  b );
-
-
-  /* Invert a transformation matrix. */
-
-  EXPORT_DEF
-  TT_Error  TT_Matrix_Invert( TT_Matrix*  matrix );
+  void  TT_Transform_Vector( TT_F26Dot6*  x,
+                             TT_F26Dot6*  y,
+                             TT_Matrix*   matrix );
 
 
   /* Compute A*B/C with 64 bits intermediate precision. */
 
   EXPORT_DEF
-  TT_Long   TT_MulDiv( TT_Long A, TT_Long B, TT_Long C );
+  TT_Long  TT_MulDiv( TT_Long  A,
+                      TT_Long  B,
+                      TT_Long  C );
 
 
   /* Compute A*B/0x10000 with 64 bits intermediate precision. */
   /* Useful to multiply by a 16.16 fixed float value.         */
 
   EXPORT_DEF
-  TT_Long   TT_MulFix( TT_Long A, TT_Long B );
+  TT_Long  TT_MulFix( TT_Long  A,
+                      TT_Long  B );
 
 
-
-  /* ----------------- character mappings support ------------- */
+  /* ----------------- character mapping support --------------- */
 
   /* Return the number of character mappings found in this file. */
   /* Returns -1 in case of failure (invalid face handle).        */
   /*                                                             */
-  /* DON'T USE THIS FUNCTION! IT HAS BEEN DEPRECATED!            */
+  /* DON'T USE THIS FUNCTION!  IT HAS BEEN DEPRECATED!           */
   /*                                                             */
   /* It is retained for backwards compatibility only and will    */
   /* fail on 16bit systems.                                      */
   /*                                                             */
-  /* You can now get the charmap count in the "num_CharMaps"     */
+  /* You can now get the charmap count in the `num_CharMaps'     */
   /* field of a face's properties.                               */
   /*                                                             */
 
@@ -1049,7 +1059,7 @@
   int  TT_Get_CharMap_Count( TT_Face  face );
 
 
-  /* Return the ID of charmap number 'charmapIndex' of a given face */
+  /* Return the ID of charmap number `charmapIndex' of a given face */
   /* used to enumerate the charmaps present in a TrueType file.     */
 
   EXPORT_DEF
@@ -1059,9 +1069,9 @@
                                TT_UShort*  encodingID );
 
 
-  /* Look up the character maps found in 'face' and return a handle */
-  /* for the one matching 'platformID' and 'platformEncodingID'     */
-  /* (see the TrueType specs relating to the 'cmap' table for       */
+  /* Look up the character maps found in `face' and return a handle */
+  /* for the one matching `platformID' and `platformEncodingID'     */
+  /* (see the TrueType specs relating to the `cmap' table for       */
   /* information on these ID numbers).  Returns an error code.      */
   /* In case of failure, the handle is set to NULL and is invalid.  */
 
@@ -1073,8 +1083,8 @@
 
   /* Translate a character code through a given character map   */
   /* and return the corresponding glyph index to be used in     */
-  /* a TT_Load_Glyph call.  This function returns 0 in case of  */
-  /* failure.                                                   */
+  /* a TT_Load_Glyph() call.  This function returns 0 in case   */
+  /* of failure.                                                */
 
   EXPORT_DEF
   TT_UShort  TT_Char_Index( TT_CharMap  charMap,
@@ -1087,20 +1097,19 @@
   /* Return the number of name strings found in the name table.  */
   /* Returns -1 in case of failure (invalid face handle).        */
   /*                                                             */
-  /* DON'T USE THIS FUNCTION! IT HAS BEEN DEPRECATED!            */
+  /* DON'T USE THIS FUNCTION!  IT HAS BEEN DEPRECATED!           */
   /*                                                             */
   /* It is retained for backwards compatibility only and will    */
   /* fail on 16bit systems.                                      */
   /*                                                             */
   /* You can now get the number of name strings in a face with   */
-  /* the "num_Names" field of its properties..                   */
-  /*                                                             */
+  /* the `num_Names' field of its properties.                    */
 
   EXPORT_DEF
   int  TT_Get_Name_Count( TT_Face  face );
 
 
-  /* Return the ID of the name number 'nameIndex' of a given face */
+  /* Return the ID of the name number `nameIndex' of a given face */
   /* used to enumerate the charmaps present in a TrueType file.   */
 
   EXPORT_DEF
@@ -1112,19 +1121,19 @@
                             TT_UShort*  nameID );
 
 
-  /* Return the address and length of the name number 'nameIndex' */
-  /* of a given face.  The string is part of the face object and  */
-  /* shouldn't be written to or released.                         */
-
-  /* Note that if for an invalid platformID a null pointer will   */
-  /* be returned.                                                 */
+  /* Return the address and length of the name number `nameIndex' */
+  /* of a given face in the variables `stringPtr' resp. `length'. */
+  /* The string is part of the face object and shouldn't be       */
+  /* written to or released.                                      */
+  /*                                                              */
+  /* Note that for an invalid platform ID a null pointer will be  */
+  /* returned.                                                    */
 
   EXPORT_DEF
   TT_Error  TT_Get_Name_String( TT_Face      face,
                                 TT_UShort    nameIndex,
-                                TT_String**  stringPtr, /* pointer address */
-                                TT_UShort*   length );  /* string length
-                                                           address */
+                                TT_String**  stringPtr,
+                                TT_UShort*   length );
 
 
 #ifdef __cplusplus
