@@ -4,7 +4,7 @@
  *
  *    Generic object cache
  *
- *  Copyright 1996-1998 by
+ *  Copyright 1996-1999 by
  *  David Turner, Robert Wilhelm, and Werner Lemberg.
  *
  *  This file is part of the FreeType project, and may only be used
@@ -99,24 +99,24 @@
   typedef TT_Error  TDestructor ( void*  object );
 
   typedef TConstructor  TRefresher;
-  typedef TDestructor   TFinaliser;
+  typedef TDestructor   TFinalizer;
 
   typedef TConstructor*  PConstructor;
   typedef TDestructor*   PDestructor;
   typedef TRefresher*    PRefresher;
-  typedef TFinaliser*    PFinaliser;
+  typedef TFinalizer*    PFinalizer;
 
 
   /* A Cache class record holds the data necessary to define */
   /* a cache kind.                                           */
   struct  TCache_Class_
   {
-    Long          object_size;
+    ULong         object_size;
     Long          idle_limit;
     PConstructor  init;
     PDestructor   done;
     PRefresher    reset;
-    PFinaliser    finalise;
+    PFinalizer    finalize;
   };
 
   typedef struct TCache_Class_  TCache_Class;
@@ -152,7 +152,7 @@
   };
 
   typedef struct TCache_  TCache;
-  typedef TCache          *PCache;
+  typedef TCache*         PCache;
 
   /* Returns a new list element, either fresh or recycled. */
   /* Note: the returned element is unlinked.               */
