@@ -2,7 +2,7 @@
 /*                                                                          */
 /*  The FreeType project -- a free and portable quality TrueType renderer.  */
 /*                                                                          */
-/*  Copyright 1996-1998 by                                                  */
+/*  Copyright 1996-1999 by                                                  */
 /*  D. Turner, R.Wilhelm, and W. Lemberg                                    */
 /*                                                                          */
 /*  ftview:  A simple font viewer.  Now supports hinting and grayscaling    */
@@ -42,6 +42,8 @@
 /*                                                                          */
 /*  h :   toggle hinting                                                    */
 /*                                                                          */
+/*  B :   toggle sbit                                                       */
+/*                                                                          */
 /*  ESC :   exit                                                            */
 /*                                                                          */
 /*                                                                          */
@@ -50,28 +52,19 @@
 /*                                                                          */
 /****************************************************************************/
 
-#ifdef ARM
-#include "std.h"
-#include "graflink.h"
-#endif
-
-#include "freetype.h"
-#include "tterror.h"  /* for Panic() and Message() only */
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
-#include "gmain.h"
-#include "gevents.h"
-#include "gdriver.h"
+#include "blitter.h"
+#include "common.h"  /* for Panic() only */
 #include "display.h"
+#include "freetype.h"
+#include "ftxsbit.h"
 
-#ifdef ARM
-#include "armsup.c" /* pull in our routines */
-#endif
-
-#include "common.h"
+#include "gdriver.h"
+#include "gevents.h"
+#include "gmain.h"
 
 #define  Pi         3.1415926535
 
@@ -79,6 +72,13 @@
 #define  Center_X   ( Bit.width / 2 )   /* dtp */
 #define  Center_Y   ( Bit.rows  / 2 )   /* dtp */
 
+/*
+ * If Ignore_Err_Not_SBit is not defined,
+ * "Fail" increase when the glyph does not have sbit and
+ * sbit_flag is 1.
+ */
+#define  Ignore_Err_Not_SBit 1
+
   char  Header[128];
 
   TT_Engine    engine;
@@ -88,10 +88,12 @@
   TT_Glyph     glyph;
   TT_CharMap   char_map;
 
-  TT_Glyph_Metrics     metrics;
-  TT_Outline           outline;
-  TT_Face_Properties   properties;
-  TT_Instance_Metrics  imetrics;
+  TT_Big_Glyph_Metrics  metrics;
+  TT_Outline            outline;
+  TT_Face_Properties    properties;
+  TT_Instance_Metrics   imetrics;
+
+  TT_SBit_Image*  sbit;
 
   int  num_glyphs;
 
@@ -104,17 +106,24 @@
   unsigned char  autorun;
 
   int            gray_render;
+  unsigned int   sbit_flag;     /* 0 if to display outlines
+                                 * 1 if to use embedded bitmaps
+                                 * 2 if to show sbit and outline glyphs
+                                 */
+
+  int            glyph_has_sbit;
+
 
 
   static TT_Error  Reset_Scale( int  pointSize )
   {
     TT_Error  error;
-
+    TT_SBit_Strike strike;
 
     if ( (error = TT_Set_Instance_CharSize( instance, pointSize*64 )) )
     {
       RestoreScreen();
-      Message( "Error = %d.\n", error );
+      fprintf( stderr, "Error = 0x%x.\n", (int)error );
       Panic( "Could not reset instance.\n" );
     }
     TT_Get_Instance_Metrics( instance, &imetrics );
@@ -126,14 +135,21 @@
       Clear_Small();
     }
 
+    if ( TT_Get_SBit_Strike( face, instance, &strike ) )
+      glyph_has_sbit = 0;
+    else
+      glyph_has_sbit = 1;
+
     return TT_Err_Ok;
   }
-  
 
-  static TT_Error  LoadTrueTypeChar( int  idx, int  hint )
+
+  static TT_Error  LoadTrueTypeChar( int  idx,
+                                     int  hint )
   {
     int  flags;
 
+
     flags = TTLOAD_SCALE_GLYPH;
     if ( hint )
       flags |= TTLOAD_HINT_GLYPH;
@@ -142,12 +158,13 @@
   }
 
 
-  static TT_Error  Render_All( int  first_glyph, int  ptsize )
+  static TT_Error  Render_All( int  first_glyph,
+                               int  ptsize )
   {
     TT_F26Dot6  start_x, start_y, step_x, step_y, x, y;
     int         i;
 
-    TT_Error    error;
+    TT_Error    error = 0;
 
 
     start_x = 4;
@@ -163,30 +180,51 @@
 
     while ( i < num_glyphs )
     {
-      if ( !(error = LoadTrueTypeChar( i, hinted )) )
+      if ( ( glyph_has_sbit ) &&
+           ( ( sbit_flag + 1 ) & 2 )                                  &&
+           !(error = TT_Load_Glyph_Bitmap( face, instance, i, sbit )) )
+      {
+        Blit_Bitmap( &Bit,
+                     &sbit->map,
+                     gray_render ? 8 : 1,
+                     x + (sbit->metrics.horiBearingX/64),
+                     Bit.rows - y - (sbit->metrics.horiBearingY/64),
+                     gray_palette[4] );
+        metrics = sbit->metrics;
+        goto Step;
+      }
+
+      if ( ( ( !glyph_has_sbit ) ||
+             ( ( sbit_flag + 1 ) & 1 ) )                &&
+           !(error = LoadTrueTypeChar( i, hinted )) )
       {
         TT_Get_Glyph_Outline( glyph, &outline );
-        TT_Get_Glyph_Metrics( glyph, &metrics );
+        TT_Get_Glyph_Big_Metrics( glyph, &metrics );
 
         Render_Single_Glyph( gray_render, glyph, x, y );
-
-        x += ( metrics.advance / 64 ) + 1;
-
-        if ( x + imetrics.x_ppem > vio_Width )
-        {
-          x  = start_x;
-          y -= step_y;
-
-          if ( y < 10 )
-            return TT_Err_Ok;
-        }
       }
       else
+      {
+#ifdef  Ignore_Err_Not_SBit
+        if (!(( glyph_has_sbit ) &&
+             ( sbit_flag == 1 ) &&
+             ( error == TT_Err_Invalid_Glyph_Index )))
+#endif
         Fail++;
+      }
+    Step:
+      x += ( metrics.horiAdvance / 64 ) + 1;
 
+      if ( x + imetrics.x_ppem > vio_Width )
+      {
+        x  = start_x;
+        y -= step_y;
+
+        if ( y < 10 )
+            return TT_Err_Ok;
+      }
       i++;
     }
-
     return TT_Err_Ok;
   }
 
@@ -195,18 +233,20 @@
   {
     switch ( event->what )
     {
-    case event_Quit:            /* ESC or q */
+    case event_Quit:                                      /* ESC or q */
       return 0;
-      
+
     case event_Keyboard:
-      if ( event->info == 'n' ) /* Next file */
+      if ( event->info == 'n' )                           /* Next file */
         return 'n';
-      if ( event->info == 'p' ) /* Previous file */
+      if ( event->info == 'p' )                           /* Previous file */
         return 'p';
-      if ( event->info == 'h' ) /* Toggle hinting */
+      if ( event->info == 'h' )                           /* Toggle hinting */
         hinted = !hinted;
+      if ( ( event->info == 'B' ) && ( glyph_has_sbit ) ) /* Toggle sbit */
+        sbit_flag = ( sbit_flag + 1 ) % 3;
       break;
-      
+
     case event_Rotate_Glyph:
       Rotation = ( Rotation + event->info ) & 1023;
       break;
@@ -230,21 +270,24 @@
 
   static void  usage( char*  execname )
   {
-    Message( "\n" );
-    Message( "ftview: simple TrueType interpreter tester -- part of the FreeType project\n" );
-    Message( "--------------------------------------------------------------------------\n" );
-    Message( "\n" );
-    Message( "Usage: %s [options below] ppem fontname[.ttf|.ttc] ...\n",
+    fprintf( stderr,  "\n" );
+    fprintf( stderr,  "ftview: simple TrueType interpreter tester -- part of the FreeType project\n" );
+    fprintf( stderr,  "--------------------------------------------------------------------------\n" );
+    fprintf( stderr,  "\n" );
+    fprintf( stderr,  "Usage: %s [options below] ppem fontname[.ttf|.ttc] ...\n",
              execname );
-    Message( "\n" );
-    Message( "  -g     gray-level rendering (default: none)\n" );
-    Message( "\n" );
+    fprintf( stderr,  "\n" );
+    fprintf( stderr,  "  -g     gray-level rendering (default: none)\n" );
+    fprintf( stderr,  "  -r R   use resolution R dpi (default: 96)\n" );
+    fprintf( stderr,  "  -B     use embedded bitmaps (default: none)\n" );
+    fprintf( stderr,  "\n" );
 
-    exit( 1 );
+    exit( EXIT_FAILURE );
   }
 
 
-  void  main( int  argc, char**  argv ) 
+  int  main( int     argc,
+             char**  argv )
   {
     int    i, old_ptsize, orig_ptsize, file;
     int    XisSetup = 0;
@@ -252,16 +295,19 @@
     char   alt_filename[128 + 4];
     char*  execname;
     int    option;
+    int    res = 96;
 
     TT_Error  error;
     TEvent    event;
 
- 
+    TT_EBLC   eblc_table;
+
+
     execname = ft_basename( argv[0] );
 
     while ( 1 )
     {
-      option = getopt( argc, argv, "g" );
+      option = ft_getopt( argc, argv, "gr:B" );
 
       if ( option == -1 )
         break;
@@ -270,6 +316,22 @@
       {
       case 'g':
         gray_render = 1;
+        sbit_flag   = 0;
+        break;
+
+      case 'r':
+        res = atoi( ft_optarg );
+        if ( res < 1 )
+          usage( execname );
+        break;
+
+      case 'B':
+        if (!gray_render)
+#if 0
+          sbit_flag  = 1;
+#else
+          sbit_flag  = 2;
+#endif
         break;
 
       default:
@@ -278,8 +340,8 @@
       }
     }
 
-    argc -= optind;
-    argv += optind;
+    argc -= ft_optind;
+    argv += ft_optind;
 
     if ( argc <= 1 )
       usage( execname );
@@ -292,7 +354,10 @@
     /* Initialize engine */
 
     if ( (error = TT_Init_FreeType( &engine )) )
-      Panic( "Error while initializing engine, code = %d.\n", error );
+      Panic( "Error while initializing engine, code = 0x%x.\n", error );
+
+    if ( (error = TT_Init_SBit_Extension( engine )) )
+      Panic( "Error while initializing sbit extention, code = 0x%x.\n", error );
 
   NewFile:
     ptsize = orig_ptsize;
@@ -303,10 +368,10 @@
     {
       if ( argv[file][i] == '.' )
         i = 0;
-        i--; 
+      i--;
     }
 
-    filename[128] = '\0';
+    filename[128]     = '\0';
     alt_filename[128] = '\0';
 
     strncpy( filename, argv[file], 128 );
@@ -331,27 +396,39 @@
     if ( error == TT_Err_Could_Not_Open_File )
       Panic( "Could not find/open %s.\n", filename );
     else if ( error )
-      Panic( "Error while opening %s, code = %x.\n", filename, error );
+      Panic( "Error while opening %s, code = 0x%x.\n", filename, error );
 
     /* get face properties and allocate preload arrays */
 
     TT_Get_Face_Properties( face, &properties );
 
     num_glyphs = properties.num_Glyphs;
-        
+
+    glyph_has_sbit = 0;
+
+    error = TT_Get_Face_Bitmaps( face, &eblc_table );
+    if ( error == TT_Err_Ok )
+      glyph_has_sbit = 1;
+    if ( sbit_flag && !glyph_has_sbit )
+      Panic( "%s does not have embedded bitmap glyphs.\n", filename );
+
     /* create glyph */
 
     error = TT_New_Glyph( face, &glyph );
     if ( error )
       Panic( "Could not create glyph container.\n" );
 
+    error = TT_New_SBit_Image( &sbit );
+    if ( error )
+      Panic( "Could not create sbit slot.\n" );
+
     /* create instance */
 
     error = TT_New_Instance( face, &instance );
     if ( error )
       Panic( "Could not create instance for %s.\n", filename );
 
-    error = TT_Set_Instance_Resolutions( instance, 96, 96 );
+    error = TT_Set_Instance_Resolutions( instance, res, res );
     if ( error )
       Panic( "Could not set device resolutions." );
 
@@ -359,7 +436,7 @@
     {
       XisSetup = 1;
 
-      if ( gray_render ) 
+      if ( gray_render )
       {
         if ( !SetGraphScreen( Graphics_Mode_Gray ) )
           Panic( "Could not set up grayscale graphics mode.\n" );
@@ -372,7 +449,7 @@
           Panic( "Could not set up mono graphics mode.\n" );
       }
     }
-  
+
     Init_Display( gray_render );
 
     Reset_Scale( ptsize );
@@ -384,17 +461,27 @@
 
     for ( ;; )
     {
-      int  key;
+      int   key;
+      char* sbit_string;
+      static char* sbit_messages[4] =
+        { "off", "on", " if available", "NONE" };
 
+      sbit_string = sbit_messages[3];
+      if ( glyph_has_sbit )
+      {
+        if (sbit_flag >= 0 && sbit_flag < 3)
+          sbit_string = sbit_messages[sbit_flag];
+      }
 
       Clear_Display();
       Render_All( Num, ptsize );
       if ( gray_render )
         Convert_To_Display_Palette();
 
-      sprintf( Header, "%s:   Glyph: %4d  ptsize: %4d  hinting: %s",
+      sprintf( Header, "%s:   Glyph: %4d  ptsize: %4d  hinting: %s  sbit: %s",
                        ft_basename( filename ), Num, ptsize,
-                       hinted ? "on" : "off" );
+                       hinted ? "on" : "off",
+                       sbit_string );
       Display_Bitmap_On_Screen( Bit.bitmap, Bit.rows, Bit.cols );
 
 #ifndef X11
@@ -405,7 +492,7 @@
 
       Get_Event( &event );
       if ( !( key = Process_Event( &event ) ) )
-        goto Fin;
+        goto End;
 
       if ( key == 'n' )
       {
@@ -436,15 +523,17 @@
       }
     }
 
-  Fin:
+  End:
     RestoreScreen();
 
     TT_Done_FreeType( engine );
 
-    Message( "Execution completed successfully.\n" );
-    Message( "Fails = %d\n", Fail );
+    printf( "Execution completed successfully.\n" );
+    printf( "Fails = %d\n", Fail );
 
-    exit( 0 );
+    exit( EXIT_SUCCESS );      /* for safety reasons */
+
+    return 0;       /* never reached */
 }
 
 
